/**** Test  Virtual Oil Drop Panel

  Test voltage controller by
  Using analogRead to measure potentiometer as a voltage divider
  to simulate voltage in Virtual Millikan Oil Drop.  3 buttons
  on digital pin 2,3,4 provide other input.

  revision history:
  09/22/2015 Mark D. Shattuck <mds> VMon.ino
             Lab 2 part II for P371
             000 mds Starting point for assignment 2-II
  12/22/2020 000 mds convert to SimpleGate
  03/08/2020 000 mds convert to  Virtual Oil Drop Panel

  Therory of opperation:
  Use potentiometer as 5V voltage divider

           potentiometer
  5V-------|||||||||||||-------GND
             ^
             |
            A1

  A1 on sweep

**************/

int pinIn = A1;  // potentiometer pin
int pinPow = 2;  // power ON/OFF
int pinPol = 3;  // polarity +/-
int pinRes = 4;  // RESET charge (hold >3sec for EXIT)  

int voltage = 0; // variable to store the value coming from pinIn

// variables for power
int pw;            // state of power button
int ppw = 1;       // previous state of power button 
bool power = 0;    // power state ON/OFF

// variables for polarity
int pol;           // state of polarity button
int ppol;          // previous state of polarity button
int polarity = 1;  // polartity state +/-

// variables for RESET/EXIT
int res;           // state of reset button  
int pres = 1;      // previous state of reset button
bool reset = 0;    // RESET state RESET/!RESET

int cres;          // measure of time reset held down
int cexit = 15000; // ~ 3 sec held down 
bool Exit = 0;     // EXIT state EXIT/!EXIT 

unsigned long T;     // Time for delay print
long del = 1000000;  // Delay between prints in us

void setup() {
  Serial.begin(115200);              // Set up Serial library at 115200 bps

  // INPUT_PULLUP allows buttons without resistors
  pinMode(pinPow, INPUT_PULLUP);     // Set up power pin
  pinMode(pinPol, INPUT_PULLUP);     // Set up polarity pin 
  pinMode(pinRes, INPUT_PULLUP);     // Set up reset/exit pin

  // starting time
  T = micros();
}

void loop() {
  // pinIn count will represent volage across cell
  voltage = analogRead(pinIn);       // read 10-bit A/D from A1 0 - 2^10-1=1023

  // process power pin ON/OFF toggle on press
  pw = digitalRead(pinPow);
  if (pw == 0 && ppw == 1) {
    power = !power;
  }
  ppw = pw;

  // process polarity pin +/- toggle on press
  pol = digitalRead(pinPol);
  if (pol == 0 && ppol == 1) {
    if (polarity == 1) {
      polarity = -1;
    } else {
      polarity = 1;
    }
  }
  ppol = pol;

  // process RESET pin one-off on release
  res = digitalRead(pinRes);
  if (pres == 0 && res == 1 &&  !reset && !Exit) {
    reset = 1;
  }
  pres = res;

  // process EXIT pin hold ~3sec
  cres += 1 - 4 * digitalRead(pinRes);  // (+1 while press) (-3 while release)
  if (cres > cexit) cres = cexit;       // clip [0,cexit]
  if (cres < 0) cres = 0;

  // display state every del elapsed time
  if (micros() - T >= del && !Exit) {   
    T = micros();                         // reset timer

    // Voltage
    Serial.print("Voltage = ");
    Serial.print(voltage);

    // Power
    if (power) {
      Serial.print(" power= ON ");
    } else {
      Serial.print(" power=OFF ");
    }

    // polarity
    if (polarity > 0) {
      Serial.print(" polarity=(+) ");
    } else {
      Serial.print(" polarity=(-) ");
    }

    // RESET
    if (reset) {
      Serial.print(" RESET ");
      reset = 0;
    }

    // EXIT
    if (cres == cexit) {
      Serial.print(" EXIT ");
      Exit=1;
    }

    // Newline
    Serial.println();
  }
}
